# ⚡ SheepRL 🐑

<p id="logo" align="center" style="width: 50%; margin: auto;">
    <img src="https://raw.githubusercontent.com/Eclectic-Sheep/sheeprl/main/assets/images/logo_half_scaled.png">
</p>

An easy-to-use framework for reinforcement learning in PyTorch, accelerated with [Lightning Fabric](https://lightning.ai/docs/fabric/stable/).  
Please have a look at the [GitHub README](https://github.com/Eclectic-Sheep/sheeprl) for more information.

## Contacts

You can contact us for any further questions or discussions:

- Federico Belotti: federico.belotti@orobix.com
- Davide Angioni: davide.angioni@orobix.com
- Refik Can Malli: refikcan.malli@orobix.com
- Michele Milesi: michele.milesi@orobix.com